@@ -51,12 +51,17 @@ class Zentao:
         params = kwargs.pop("params", {})
         params[self.session.name] = self.session.id
 
+        # check out request body
+        data = kwargs.pop("data", {})
+
+        # get api spec
         api = self.apis.get(api_name, kwargs)
 
         response = get_json(requests.request(
             method=api.get("method", "GET"),
             url=api.get("url"),
-            params=params
+            params=params,
+            data=data
         ))
 
         # return raw response or not
